package com.hai.service;

import com.hai.entity.HighChildOrder;
import com.hai.entity.HighOrder;
import com.hai.model.HighOrderData;
import com.hai.model.HighOrderModel;

import java.util.List;
import java.util.Map;

/**
 * @Auther: 胡锐
 * @Description:
 * @Date: 2021/3/26 23:04
 */
public interface HighOrderService {

    /**
     * @Author 胡锐
     * @Description 增加订单
     * @Date 2021/3/26 23:05
     **/
    void insertOrder(HighOrder highOrder) throws Exception;

    /**
     * 修子订单信息
     * @param highChildOrder
     */
    void updateChildOrder(HighChildOrder highChildOrder);

    /**
     * @Author 胡锐
     * @Description 金币支付订单
     * @Date 2021/3/27 11:20
     **/
    void goldPayOrder(Long userId, Long orderId) throws Exception;

    /**
     * 汇联通工会卡支付
     * @param userCardId
     * @param orderId
     * @throws Exception
     */
    void hltUnionCardPay(Long userCardId, Long orderId) throws Exception;

    /**
     * @Author 胡锐
     * @Description 修改订单
     * @Date 2021/3/26 23:06
     **/
    void updateOrder(HighOrder highOrder);

    /**
     * 修改订单详情
     * @param highOrder
     */
    void updateOrderDetail(HighOrder highOrder);

    /**
     * @Author 胡锐
     * @Description 获取未完成的子订单数量
     * @Date 2021/3/27 13:35
     **/
    Integer getUndoneChildOrder(Long orderId);

    /**
     * @Author 胡锐
     * @Description 查询子商品
     * @Date 2021/4/5 13:23
     **/
    HighChildOrder getChildOrderById(Long childOrderId);

    /**
     * @Author 胡锐
     * @Description 根据用户和商品id 查询
     * @Date 2021/4/15 21:38
     **/
    HighChildOrder getChildOrderByUserGoods(Long userId,Integer goodsType,Long goodsId);

    /**
     * 根据订单id 查询子商品
     * @param orderId
     * @return
     */
    List<HighChildOrder> getChildOrderByOrder(Long orderId);

    /**
     * @Author Sum1Dream
     * @name getChildOrderByPresentation.java
     * @Description // 根据是否赠品查询子订单
     * @Date 16:20 2021/9/7
     * @Param [orderId, isGiveAway]
     * @return com.hai.entity.HighChildOrder
     **/
    HighChildOrder getChildOrderByPresentation(Long orderId);

    /**
     * @Author 胡锐
     * @Description 查询子商品列表
     * @Date 2021/4/2 21:51
     **/
    List<HighChildOrder> getChildOrderList(Map<String, Object> map);

    /**
     * @Author 胡锐
     * @Description 根据id查询
     * @Date 2021/3/26 23:06
     **/
    HighOrder getOrderById(Long id);

    /**
     * @Author 胡锐
     * @Description 根据订单号查询
     * @Date 2021/3/27 0:38
     **/
    HighOrder getOrderByOrderNo(String orderNo);

    /**
     * @Author 袁野
     * @Description 查询订单列表
     * @Date 2021/3/26 23:06
     **/
    List<HighOrderData> getOrderBList(Map<String,Object> map);

    /**
     * @Author 胡锐
     * @Description 查询订单列表
     * @Date 2021/3/26 23:06
     **/
    List<HighOrder> getOrderList(Map<String,Object> map);

    /**
     * 查询订单列表
     * @param map
     * @return
     */
    List<HighOrderModel> getGoodsOrderModelList(Map<String,Object> map) throws Exception;

    /**
     * 查询加油订单
     * @param map
     * @return
     * @throws Exception
     */
    List<HighOrderModel> getGasOrderModelList(Map<String,Object> map) throws Exception;

    /**
     * 查询肯德基订单
     * @param map
     * @return
     * @throws Exception
     */
    List<HighOrderModel> getKfcOrderModelList(Map<String,Object> map) throws Exception;

    /**
     * 查询电影订单
     * @param map
     * @return
     * @throws Exception
     */
    List<HighOrderModel> getCinemaOrderList(Map<String,Object> map) throws Exception;

    /**
     * 查询话费充值订单
     * @param map
     * @return
     * @throws Exception
     */
    List<HighOrderModel> getMobileOrderList(Map<String,Object> map) throws Exception;

    /**
     * 根据标识码 查询订单
     * @param identificationCode
     * @return
     * @throws Exception
     */
    List<HighOrderModel> getOrderListByIdCode(String identificationCode, Map<String,Object> map) throws Exception;

    /**
     * @Author 胡锐
     * @Description 查询需要关闭的订单列表
     * @Date 2021/3/27 15:43
     **/
    List<HighOrder> getCloseOrder();

    /**
     * 根据优惠券代理商id 查询已消费的订单
     * @param discountCodeId
     * @return
     */
    HighOrder getConsumeOrderByDiscountCode(Long discountCodeId);

    /**
     * @Author 胡锐
     * @Description 子订单完成
     * @Date 2021/3/27 13:28
     **/
    void childOrderComplete(Long childOrderId);

    /**
     * @Author 胡锐
     * @Description 取消订单
     * @Date 2021/3/27 15:50
     **/
    void cancelOrder(Long orderId);

    /**
     * @Author 袁野
     * @Description 根据用户查询订单统计
     * @Date 2021/3/27 15:50
     **/
    Integer countOrderByUserId(Long memId , Integer status);

    /**
     * @Author 袁野
     * @Description 未使用优惠券数量
     * @Date 2021/3/27 15:50
     **/
    Integer countUnusedDiscountByUserId(Long userId , Integer status);

    /**
     * 查询处于已经支付和待支付的话费订单
     * @return
     */
    List<HighOrder> getAlreadyPaidMobileOrder();

    /**
     * 查询处于已经支付和待支付的KFC订单
     * @return
     */
    List<HighOrder> getAlreadyPaidKfcOrder();

    /**
     * 查询处于已经支付和待支付的话费订单
     * @return
     */
    List<HighOrder> getAlreadyPaidCinemaOrder();


    List<HighOrder> getTest();

    /**
     * 查询团油超过支付时间24小时订单
     * @return
     */
    List<Map<String,Object>> getFinishGasOrder();

}
